"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
require("dotenv/config");
const logger_1 = require("../logger");
const main_1 = require("./main");
const options_1 = require("./options");
// eslint-disable-next-line @typescript-eslint/no-var-requires
const pkg = require('../../package.json');
commander_1.program
    .version(pkg.version)
    .description('CLI app to monitor & download Twitter Spaces.')
    .option('-d, --debug', 'Show debug logs')
    .option('--env <ENV_PATH>', 'Path to .env file, default to current working folder (See .env.example)')
    .option('--config <CONFIG_PATH>', 'Path to config file (See config.example.json)')
    .option('--user <USER>', 'Monitor & download live Spaces from users, separate by comma (,)')
    .option('--id <SPACE_ID>', 'Monitor & download live Space with its id')
    .option('-surl, --space-url <SPACE_URL>', 'Monitor & download live Space with its URL')
    .option('--force', 'Force download Space when using with --id')
    .option('--url <PLAYLIST_ID>', 'Download Space using playlist url')
    .option('--notification', 'Show notification about new live Space')
    .option('--force-open', 'Force open Space in browser');
commander_1.program.action((args, command) => {
    options_1.options.debug = command.getOptionValue('debug');
    if (options_1.options.debug) {
        (0, logger_1.toggleDebugConsole)();
    }
    options_1.options.env = command.getOptionValue('env');
    options_1.options.config = command.getOptionValue('config');
    options_1.options.user = command.getOptionValue('user');
    options_1.options.id = command.getOptionValue('id');
    options_1.options.url = command.getOptionValue('url');
    options_1.options.notification = command.getOptionValue('notification');
    options_1.options.forceOpen = command.getOptionValue('forceOpen');
    (0, main_1.bootstrap)();
});
//# sourceMappingURL=cmd.js.map