"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SpaceTracker = void 0;
const events_1 = __importDefault(require("events"));
const open_1 = __importDefault(require("open"));
const PeriscopeApi_1 = require("../../../apis/PeriscopeApi");
const logger_1 = require("../../../logger");
const options_1 = require("../../options");
const twitter_public_space_api_service_1 = require("../twitter/services/apis/twitter-public-space-api.service");
const twitter_space_utils_1 = require("../twitter/utils/twitter-space.utils");
class SpaceTracker extends events_1.default {
    constructor(id, moduleRef) {
        super();
        this.id = id;
        this.moduleRef = moduleRef;
        this.chunkVerifyCount = 0;
        this.isNotificationNotified = false;
        this.logger = logger_1.baseLogger.child({ context: `[SpaceTracker@${id}]` });
        this.openUrl();
    }
    get url() {
        return twitter_space_utils_1.TwitterSpaceUtils.getUrl(this.id);
    }
    get metadata() {
        return this.audioSpace?.metadata;
    }
    async track() {
        await this.initData();
    }
    async initData() {
        if (!this.audioSpace) {
            await this.getAudioSpace();
        }
        // this.dynamicPlaylistUrl = options.url
        // if (this.dynamicPlaylistUrl) {
        //   // TODO
        // }
        if (!this.liveVideoStreamStatus) {
            await this.getLiveVideoStreamStatus();
        }
        if (!this.dynamicPlaylistUrl) {
            this.getDynamicPlaylistUrl();
        }
        if (!this.accessChat) {
            await this.getAccessChat();
        }
        // if (this.metadata.state === SpaceMetadataState.ENDED) {
        //   this.processDownload()
        //   return
        // }
        debugger;
    }
    // #region Data
    async getDynamicPlaylistUrl() {
        const url = this.liveVideoStreamStatus.source.location;
        this.logger.info('getDynamicPlaylistUrl', { url });
        this.dynamicPlaylistUrl = url;
    }
    async getAudioSpace() {
        const data = await this.moduleRef
            .get(twitter_public_space_api_service_1.TwitterPublicSpaceApiService, { strict: false })
            .getAudioSpaceById(this.id);
        delete data.sharings;
        this.logger.debug('getAudioSpace#audioSpace', data);
        this.logger.info('getAudioSpace#metadata', data?.metadata);
        this.audioSpace = data;
    }
    async getLiveVideoStreamStatus() {
        const data = await this.moduleRef
            .get(twitter_public_space_api_service_1.TwitterPublicSpaceApiService, { strict: false })
            .getLiveVideoStreamStatus(this.metadata?.media_key);
        this.logger.debug('getLiveVideoStreamStatus', data);
        this.liveVideoStreamStatus = data;
    }
    async getAccessChat() {
        const data = await PeriscopeApi_1.PeriscopeApi.getAccessChat(this.liveVideoStreamStatus.chatToken);
        this.logger.debug('getAccessChat', data);
        this.logger.info('getAccessChat', { endpoint: data.endpoint, accessToken: data.access_token });
        this.accessChat = data;
    }
    // #endregion
    // #region Downloader
    async downloadSpace() {
        await Promise.all([
            this.downloadSpaceAudio(),
            this.downloadSpaceCaptions(),
        ]);
    }
    async downloadSpaceAudio() {
        // TODO
        debugger;
    }
    async downloadSpaceCaptions() {
        // TODO
        debugger;
    }
    // #endregion
    // #region Noticication
    async openUrl() {
        if (!options_1.options.forceOpen) {
            return;
        }
        try {
            // Opens Space in the default browser
            await (0, open_1.default)(this.url);
        }
        catch (error) {
            this.logger.error(`openUrl: ${error.message}`);
        }
    }
}
exports.SpaceTracker = SpaceTracker;
//# sourceMappingURL=space-tracker.js.map